abacusai.abacus_api — AbacusAI documentation

# `abacusai.abacus_api`

## Module Contents

### Classes

`AbacusApi` | An Abacus API.

class abacusai.abacus_api.AbacusApi(client, method=None, docstring=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  An Abacus API.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - method (str) – The name of of the API method.

    - docstring (str) – The docstring of the API method.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict